import requests, zipfile,sys,os,tarfile
zip_file_url = "https://www.s79.ir/tmp/blankProject.tar.gz"


print("""
███████╗██╗░░░░░░█████╗░░██████╗██╗░░██╗
██╔════╝██║░░░░░██╔══██╗██╔════╝██║░██╔╝
█████╗░░██║░░░░░███████║╚█████╗░█████═╝░
██╔══╝░░██║░░░░░██╔══██║░╚═══██╗██╔═██╗░
██║░░░░░███████╗██║░░██║██████╔╝██║░╚██╗
╚═╝░░░░░╚══════╝╚═╝░░╚═╝╚═════╝░╚═╝░░╚═╝
""")
print("Flask project manager, version 2.7")
print("Initializing new flask project....")
print("Downloading requirements ....")

def main():
    r = requests.get(zip_file_url, stream=True)
    with open('tmp.tgz', 'wb') as file:
        file.write(r.raw.read())
    tar = tarfile.open("tmp.tgz")
    tar.extractall(path=os.getcwd())
    tar.close()
    print("Operation done!")
    print("Project path: " + os.getcwd())
    os.remove('tmp.tgz')


if __name__ == '__main__':
    main()

if __name__ == 'flask_project_manager.__main__':
    main()



from setuptools import setup, find_packages


setup(
    name='flask_project_manager',
    version='2.7.1',
    license='MIT',
    author="Raja Osian",
    author_email='omid22ssh@gmail.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/sinasox/sina_seifouri',
    keywords='This is just an introduction.',
    entry_points={
        'console_scripts': [
            'flask_project_manager=flask_project_manager:main'
        ]
    },
    install_requires=[
    'requests'

    ],

)
